from typing import Literal

from nagiosplugin.result import Results

class Summary:
    def ok(self, results: Results) -> str: ...
    def problem(self, results: Results) -> str: ...
    def verbose(self, results: Results) -> list[str]: ...
    def empty(self) -> Literal["no check results"]: ...



from typing import Callable, Iterator, Protocol

from nagiosplugin.metric import Metric
from nagiosplugin.performance import Performance
from nagiosplugin.range import Range
from nagiosplugin.resource import Resource
from nagiosplugin.result import Result
from nagiosplugin.state import ServiceState

FmtMetric = str | Callable[[Metric, Context], str]

class ResultCls(Protocol):
    def __call__(
        self, state: ServiceState, hint: str | None = ..., metric: Metric | None = ...
    ) -> Result: ...

RangOrString = Range | str

class Context:
    name: str
    fmt_metric: FmtMetric
    result_cls: ResultCls
    def __init__(
        self, name: str, fmt_metric: FmtMetric = ..., result_cls: ResultCls = ...
    ) -> None: ...
    def evaluate(self, metric: Metric, resource: Resource) -> Result: ...
    def performance(self, metric: Metric, resource: Resource) -> Performance: ...
    def describe(self, metric: Metric) -> str | None: ...

class ScalarContext(Context):
    def __init__(
        self,
        name: str,
        warning: RangOrString = ...,
        critical: RangOrString = ...,
        fmt_metric: FmtMetric = ...,
        result_cls: Result = ...,
    ) -> None: ...
    def evaluate(self, metric: Metric, resource: Resource) -> Result: ...
    def performance(self, metric: Metric, resource: Resource) -> Performance: ...

class Contexts:
    by_name: dict[str, Context]

    def __init__(self) -> None: ...
    def add(self, context: Context) -> Context: ...
    def __getitem__(self, context_name: str) -> Context: ...
    def __contains__(self, context_name: str) -> Context: ...
    def __iter__(self) -> Iterator[Context]: ...



from typing import Literal

from nagiosplugin.context import Context, Contexts
from nagiosplugin.resource import Resource
from nagiosplugin.result import Results
from nagiosplugin.state import ServiceState
from nagiosplugin.summary import Summary

class Check:
    resources: list[Resource]
    contexts: Contexts
    summary: Summary
    results: Results
    perfdata: list[str]
    name: str

    def __init__(self, *objects: Resource | Context | Summary | Results) -> None: ...
    def add(self, *objects: Resource | Context | Summary | Results) -> Check: ...
    def __call__(self) -> None: ...
    def main(self, verbose: bool = ..., timeout: int = ...) -> None: ...
    @property
    def state(self) -> ServiceState: ...
    @property
    def summary_str(self) -> str: ...
    @property
    def verbose_str(self) -> list[str] | str: ...
    @property
    def exitcode(self) -> Literal[0, 1, 2, 3]: ...



from nagiosplugin.check import Check as Check
from nagiosplugin.context import Context as Context, ScalarContext as ScalarContext
from nagiosplugin.cookie import Cookie as Cookie
from nagiosplugin.error import CheckError as CheckError, Timeout as Timeout
from nagiosplugin.logtail import LogTail as LogTail
from nagiosplugin.metric import Metric as Metric
from nagiosplugin.multiarg import MultiArg as MultiArg
from nagiosplugin.performance import Performance as Performance
from nagiosplugin.range import Range as Range
from nagiosplugin.resource import Resource as Resource
from nagiosplugin.result import Result as Result, Results as Results
from nagiosplugin.runtime import Runtime as Runtime, guarded as guarded
from nagiosplugin.state import (
    Critical as Critical,
    Ok as Ok,
    Unknown as Unknown,
    Warn as Warn,
)
from nagiosplugin.summary import Summary as Summary
from nagiosplugin.version import __VERSION__

__version__: str = ...



from io import StringIO
from logging import StreamHandler
from typing import Callable, NoReturn, ParamSpec, TypeVar

from nagiosplugin.check import Check
from nagiosplugin.output import Output

P = ParamSpec("P")
R = TypeVar("R")

def guarded(
    original_function: Callable[P, R], verbose: bool = ...
) -> Callable[P, R]: ...

class Runtime:
    instance: Runtime = ...
    check: Check = ...
    _verbose: int = ...
    timeout: int = ...
    logchan: StreamHandler[StringIO] = ...
    output: Output = ...
    stdout: StringIO = ...
    exitcode: int = ...
    def __new__(cls) -> Runtime: ...
    def __init__(self) -> None: ...
    @property
    def verbose(self) -> int: ...
    @verbose.setter
    def verbose(self, verbose: int) -> None: ...
    def run(self, check: Check) -> None: ...
    def execute(
        self, check: Check, verbose: bool = ..., timeout: int = ...
    ) -> NoReturn: ...
    def sysexit(self) -> NoReturn: ...



from dataclasses import dataclass
from typing import Any, Literal

def zap_none(val: Any | None) -> Any | Literal[""]: ...
def quote(label: str) -> str: ...
@dataclass
class Performance:

    label: str
    value: Any
    uom: str | None = None
    warn: float | None = None
    crit: float | None = None
    min: float | None = None
    max: float | None = None

    def __str__(self) -> str: ...



from io import StringIO
from logging import StreamHandler
from typing import Literal, Sequence

from nagiosplugin.check import Check

def filter_output(output: str, filtered: str) -> str: ...

class Output:

    ILLEGAL: Literal["|"] = ...

    logchan: StreamHandler[StringIO]
    verbose: int
    status: str
    out: list[str]
    warnings: list[str]
    longperfdata: list[str]

    def __init__(
        self, logchan: StreamHandler[StringIO], verbose: int = ...
    ) -> None: ...
    def add(self, check: Check) -> None: ...
    def format_status(self, check: Check) -> str: ...
    def format_perfdata(self, check: Check, linebreak: int = ...) -> str: ...
    def add_longoutput(self, text: str | Sequence[str]) -> None: ...
    def __str__(self) -> str: ...



from dataclasses import dataclass
from typing import Literal

def worst(states: list[ServiceState]) -> ServiceState: ...
@dataclass
class ServiceState:
    code: Literal[0, 1, 2, 3]
    text: Literal["ok", "warning", "critical", "unknown"]

    def __str__(self) -> str: ...
    def __int__(self) -> Literal[0, 1, 2, 3]: ...

Ok: ServiceState = ...

Warn: ServiceState = ...

Critical: ServiceState = ...

Unknown: ServiceState = ...



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nagiosplugin-stubs']

package_data = \
{'': ['*'], 'nagiosplugin-stubs': ['examples/*', 'platform/*']}

install_requires = \
['typing-extensions>=4.3.0,<5.0.0']

setup_kwargs = {
    'name': 'nagiosplugin-stubs',
    'version': '0.4.0',
    'description': 'Type stubs for the nagiosplugin package.',
    'long_description': 'nagiosplugin-stubs\n==================\n\nType stubs for the nagiosplugin package.\n\nOther stub packages\n\n* https://github.com/lxml/lxml-stubs\n* https://github.com/tk0miya/docutils-stubs\n',
    'author': 'Josef Friedrich',
    'author_email': 'josef@friedrich.rocks',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/Josef-Friedrich/nagiosplugin-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



class Range:
    invert: bool
    start: float | int
    end: float | int

    def __init__(self, spec: str | int | Range = ...) -> None: ...
    def __new__(cls, spec: str | int | Range = ...) -> Range: ...
    def match(self, value: float | int) -> bool: ...
    def __contains__(self, value: float | int) -> bool: ...
    def __str__(self) -> str: ...
    def __repr__(self) -> str: ...
    @property
    def violation(self) -> str: ...
